﻿using System;
using System.IO;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using VisualSite;

public partial class Admin_Components_FileBrowser : System.Web.UI.UserControl
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Render files in file folder
        DirectoryInfo dir = new DirectoryInfo(Server.MapPath(Constants.FILE_FOLDER));
        if (dir.Exists)
        {
            FileInfo[] files = dir.GetFiles();
            repeater.DataSource = files;
            repeater.DataBind();
        }
        else
        {
            lblMessage.Text = String.Format("Directory [{0}] not found. This folder needs to exist to upload files into it.", dir.Name);
            lblMessage.Visible = true;
        }
    }

    /// <summary>
    /// Gets the relative path of an image for rendering 
    /// </summary>
    /// <param name="file"></param>
    /// <returns></returns>
    protected string GetImagePath(FileInfo file)
    {
        return ResolveUrl(Constants.FILE_FOLDER) + file.Name;
    }

    /// <summary>
    /// Gets the name of an image for rendering 
    /// </summary>
    /// <param name="file"></param>
    /// <returns></returns>
    protected string GetImageName(FileInfo file)
    {
        string result = file.Name;
        if (result.Length > 16) result = result.Remove(15) + "...";
        return result;
    }

    /// <summary>
    /// Gets the thumbnail url of a file for rendering
    /// </summary>
    /// <param name="file"></param>
    /// <returns></returns>
    protected string GetImageUrl(FileInfo file)
    {
        string result = String.Empty;
        if (file.Extension.ToLower() == ".jpg" || file.Extension.ToLower() == ".gif" || file.Extension.ToLower() == ".png")
        {
            result = ResolveUrl(Constants.FILE_FOLDER + file.Name);
        }
        else
        {
            result = ResolveUrl(Constants.GENERIC_FILE_IMAGE);
        }
        return result;
    }

    /// <summary>
    /// Deletes files selected in browser
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void DeleteSelectedFiles(object sender, EventArgs e)
    {
        string files = String.Empty;
        foreach (RepeaterItem item in repeater.Items)
        {
            string name = item.ID;
            CheckBox chk = item.FindControl("chkImage") as CheckBox;
            if (chk.Checked == true)
            {
                FileInfo file = new FileInfo(Server.MapPath(Constants.FILE_FOLDER + chk.ToolTip));
                if (file.Exists)
                {
                    files += file.Name + ", ";
                    file.Delete();
                    lblMessage.Visible = true;
                }
            }
        }
        lblMessage.Text = String.Format(Utils.Localise("msgFilesDeleted"), files);
        // Refresh
        Page_Load(null, null);
    }

    /// <summary>
    /// Adds files to existing (or new) post
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void AddSelectedFiles(object sender, EventArgs e)
    {
        string files = String.Empty;
        foreach (RepeaterItem item in repeater.Items)
        {
            string name = item.ID;
            CheckBox chk = item.FindControl("chkImage") as CheckBox;
            if (chk.Checked == true)
            {
                FileInfo file = new FileInfo(Server.MapPath(Constants.FILE_FOLDER + chk.ToolTip));
                if (file.Exists)
                {
                    files += file.Name + ",";
                }
            }
        }
        Response.Redirect(String.Format(Constants.RAW_URL, -1) + "&AddFiles=" + files);
    }

}
