﻿using System;
using System.IO;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;
using VisualSite;

public partial class Admin_Components_Uploader : System.Web.UI.UserControl
{
    // Allowed Extensions
    protected string[] AllowedExtensions = new string[8] { "jpg", "png", "gif", "pdf", "doc", "ppt", "mp3", "wav" };

    protected void DoUploadFile(object sender, EventArgs e)
    {
        if (fileUploader.HasFile)
        {
            string filePath = fileUploader.PostedFile.FileName;
            string fileName = filePath.Substring(filePath.LastIndexOf("\\") + 1, filePath.Length - filePath.LastIndexOf("\\") - 1);
            string fileExtension = filePath.Substring(filePath.LastIndexOf(".") + 1, filePath.Length - filePath.LastIndexOf(".") - 1).ToLower();
            string targetLocation = Server.MapPath(Constants.FILE_FOLDER + fileName);
            try
            {
                // Check extension
                if (!(String.Join(",", AllowedExtensions).Contains(fileExtension)))
                {
                    throw new Exception(String.Format(Utils.Localise("msgFileExtNotAllowed"), String.Join(", ", AllowedExtensions)));
                }
                // Check if file exists
                else if (File.Exists(targetLocation))
                {
                    throw new Exception(String.Format(Utils.Localise("msgFileAlreadyExists"), fileName));
                }
                // Check file Size
                else if (fileUploader.FileBytes.Length > Constants.MAX_UPLOAD_SIZE)
                {
                    throw new Exception(String.Format(Utils.Localise("msgFileTooBig"), Math.Round(Convert.ToDecimal(fileUploader.FileBytes.Length) / 1000000, 2), Convert.ToDecimal(Constants.MAX_UPLOAD_SIZE) / 1000000));
                }
                else
                {
                    // Save
                    fileUploader.SaveAs(targetLocation);
                    // Resize JPGs
                    if (fileExtension == "jpg") ResizeImage(targetLocation);
                    lblMessage.Text = String.Format(Utils.Localise("msgFileSaved"), fileName);
                }
            }
            catch (Exception ex)
            {
                lblMessage.Text = String.Format(Utils.Localise("msgFileSaveError"), ex.Message);
            }
            lblMessage.Visible = true;
        }
        // Refresh page
        Response.Redirect(Request.Path);
    }

    private void ResizeImage(string imagePath)
    {
        if (File.Exists(imagePath))
        {
            // Initialise Default size
            int width = Constants.IMG_WIDTH_2;
            int height = width / 3 * 2;
            // Determine width
            if (chkSize1.Checked) width = Constants.IMG_WIDTH_1;
            if (chkSize2.Checked) width = Constants.IMG_WIDTH_2;
            if (chkSize3.Checked) width = Constants.IMG_WIDTH_3;
            // Delete temp file if it already exists
            string tempLocation = Server.MapPath(Constants.FILE_FOLDER + "temp.jpg");
            if (File.Exists(tempLocation)) File.Delete(tempLocation);
            // Copy file to temp
            File.Copy(imagePath, tempLocation);
            using (System.Drawing.Image image = System.Drawing.Image.FromFile(tempLocation))
            {
                if (image.Width >= width)
                {
                    // Determine height and width
                    if (image.Width > image.Height)
                    {
                        //width = width;
                        height = Convert.ToInt32((Convert.ToDouble(width) / Convert.ToDouble(image.Width)) * image.Height);
                    }
                    else
                    {
                        height = width;
                        width = Convert.ToInt32((Convert.ToDouble(height) / Convert.ToDouble(image.Height)) * image.Width);
                    }

                    // Initialize Image
                    using (Bitmap resizedImage = new Bitmap(width, height, PixelFormat.Format16bppRgb555))
                    {

                        resizedImage.SetResolution(image.HorizontalResolution, image.VerticalResolution);

                        // Resize Graphics
                        using (Graphics grPhoto = Graphics.FromImage(resizedImage))
                        {
                            grPhoto.InterpolationMode = InterpolationMode.HighQualityBicubic;
                            grPhoto.DrawImage(image, new Rectangle(-1, -1, width + 1, height + 1), new Rectangle(0, 0, image.Width, image.Height), GraphicsUnit.Pixel);
                            grPhoto.Dispose();

                            // Save
                            resizedImage.Save(imagePath);
                        }
                    }
                }
            }
            File.Delete(tempLocation);
        }

    }
}
