using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Security.AccessControl;
using System.Security.Principal;
using VisualSite;

public partial class Admin_DBManager : System.Web.UI.Page
{
    protected void Page_PreInit(object sender, EventArgs e)
    {
        if (Utils.TemplateFile != String.Empty)
            Page.MasterPageFile = Utils.TemplateFile;
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        // DB READ TEST
        try
        {
            DAL.CheckRead(false);
            lblDbReadStatus.Text = Utils.Localise("msgSuccess") as string;
            lblDbReadStatus.CssClass = "vs-strong vs-green";
        }
        catch (Exception ex)
        {
            string message = (ex.Message.Length > 15) ? ex.Message.Substring(0, 15) + "..." : ex.Message;
            lblDbWriteStatus.Text = Utils.Localise("msgConnectionError") as string + " " + message;
            lblDbWriteStatus.ToolTip = Utils.Localise("msgConnectionError") as string + " " + ex.Message;
            lblDbReadStatus.CssClass = "vs-strong vs-red";
        }

        //DB WRITE TEST
        try
        {
            DAL.CheckWrite(false);
            lblDbWriteStatus.Text = Utils.Localise("msgSuccess") as string;
            lblDbWriteStatus.CssClass = "vs-strong vs-green";
        }
        catch (Exception ex)
        {
            string message = (ex.Message.Length > 15) ? ex.Message.Substring(0, 15) + "..." : ex.Message;
            lblDbWriteStatus.Text = Utils.Localise("msgConnectionError") as string + " " + message;
            lblDbWriteStatus.ToolTip = Utils.Localise("msgConnectionError") as string + " " + ex.Message;
            lblDbWriteStatus.CssClass = "vs-strong vs-red";
        }

        // BACKUPS
        if (!String.IsNullOrEmpty(DAL.DataFile))
        {
            FileInfo dbFile = new FileInfo(DAL.DataFile);
            if (dbFile.Exists)
            {
                FileInfo[] backupFiles = dbFile.Directory.GetFiles("*.mdb.bak");
                if (backupFiles != null)
                {
                    listBackups.DataSource = backupFiles;
                    listBackups.DataBind();
                }
            }
        }
        if (!Utils.IsDatabaseBackedUp)
            btnBakup.Enabled = true;
    }

    private long DBFileSize
    {
        get
        {
            if (String.IsNullOrEmpty(DAL.DataFile))
                return 0;
            FileInfo file = new FileInfo(DAL.DataFile);
            return file.Length / 1000 * 1000;
        }
    }

    protected string DBSize
    {
        get
        {
            long size = this.DBFileSize;
            return Convert.ToString(size / 1000000.00) + " MB";
        }
    }

    protected string DBSizeMeter
    {
        get
        {
            string result = String.Empty;
            long size = this.DBFileSize;
            long maxDBSize = Constants.MAX_DB_SIZE;
            long medDBSize = maxDBSize * 4 / 5;
            long smallDBSize = maxDBSize * 2 / 5;
            string status = "<div class=\"vs-database-meter\" style=\"background-color:{0};width:{1}%\" />{2}</div>";
            if (size < smallDBSize)
            {
                result = String.Format(status, "#99FF66", Convert.ToString(size * 100 / maxDBSize), Utils.Localise("lblSmall"));
            }
            else if (size < medDBSize)
            {
                result = String.Format(status, "#FFFF66", Convert.ToString(size * 100 / maxDBSize), Utils.Localise("lblMedium"));
            }
            else if (size < maxDBSize)
            {
                result = String.Format(status, "#FF9933", Convert.ToString(size * 100 / maxDBSize), Utils.Localise("lblLarge"));
            }
            else
            {
                result = String.Format(status, "#FF3300", "100", Utils.Localise("lblOversize"));
            }
            return result;
        }
    }

    protected void CreateBackup(object sender, EventArgs e)
    {
        try { 
            Utils.BackupDatabase();
            Response.Redirect(Request.Path, true);
        }
        catch (Exception ex)
        {
            lblMessage.Text = Utils.Localise("msgBackupError") + " " + ex.Message;
            lblMessage.Visible = true;
        }
    }
}
