﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using VisualSite;
using VisualSite.Entities;

public partial class Admin_Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Page.IsPostBack)
        {
            if (String.IsNullOrEmpty(Request["Login"]))
                Utils.GoHome();
            if (!String.IsNullOrEmpty(Request.Form["txtUsername"]))
            {
                // Obtain username and password
                string username = Request.Form["txtUsername"] as string;
                string password = Request.Form["txtPassword"] as string;
                // Check account is unlocked
                if (CheckAccountLocked(username))
                {
                    // User account is locked, notify to try again in 5 min
                    lblMessage.Text = Utils.Localise("msgAccountLocked");
                    lblMessage.Visible = true;
                }
                else
                {
                    // Check user validation
                    if (ValidateUser(username, password))
                    {
                        // Backup Database 
                        if (Utils.GetSetting("Backup") == "ON")
                            Utils.BackupDatabase();
                        // Set authentication
                        FormsAuthentication.SetAuthCookie(Request.Form["txtUsername"], false);
                        // Redirect
                        if (String.IsNullOrEmpty(Request.QueryString["ReturnUrl"]))
                            Utils.GoHome();
                        else
                            Response.Redirect(Request.QueryString["ReturnUrl"]);
                    }
                    else
                    {
                        // Username or password do not match
                        lblMessage.Text = Utils.Localise("msgPasswordError");
                        lblMessage.Visible = true;
                    }
                }
            }
        }
    }

    protected bool CheckAccountLocked(string username)
    {
        // Instantiate user
        User user = null;
        try { user = DAL.GetUser(username); }
        catch
        {
            // Database error (connection severed). Refresh cache & Go home.
            Utils.ClearCache();
            Utils.GoHome();
        }
        // No user = no lock.
        if (user == null)
            return false;
        // Check if the account was locked less than 5 mins ago;
        if (user.LockedDate > DateTime.Now.AddMinutes(-5))
            return true;
        return false;
    }

    protected bool ValidateUser(string username, string password)
    {
        // Instantiate user
        User user = null;
        try { user = DAL.GetUser(username); }
        catch { }
        // If username doesnt match then login fails
        if (user == null)
            return false;
        // Check password and validate if correct
        if (user.Password == password)
            return true;
        // Otherwise its the wrong password, 
        // lock the user when they try > 3 times in 5 minutes
        int tries = 0;
        try {tries = Convert.ToInt32(HttpContext.Current.Cache[username + "-LoginAttempts"]);}
        catch { }
        if (tries > 2)
        {
            // 5th time.. Lock the account
            DAL.UpdateUser(user.ID, user.Username, user.Password, DateTime.Now);
            HttpContext.Current.Cache.Remove(username + "-LoginAttempts");
        }
        else
            // Add login attempts to cache for 5 minutes
            if (tries == 0)
                Utils.AddToCache(username + "-LoginAttempts", tries + 1, 5);
            else
                HttpContext.Current.Cache[username + "-LoginAttempts"] = tries + 1;
        return false;
    }
}
