using System;
using System.Text;
using System.Xml;
using System.Collections;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using VisualSite;

public partial class Admin_Menu : System.Web.UI.Page
{
    protected bool TreeMode = true; // Default to tree mode

    protected void Page_PreInit(object sender, EventArgs e)
    {
        if (Utils.TemplateFile != String.Empty)
            Page.MasterPageFile = Utils.TemplateFile;
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!String.IsNullOrEmpty(Request.QueryString["mode"]))
            if (Request.QueryString["mode"].ToLower() == "list")
                TreeMode = false;
    }

    protected void Refresh(object sender, EventArgs e)
    {
        grid.DataBind();
    }

    protected void RefreshMenu(object sender, EventArgs e)
    {
        SimpleSiteMapProvider.ClearFromCache();
    }

    protected void OnRowUpdating(object sender, GridViewUpdateEventArgs e)
    {
        if (e.RowIndex == 0)
        {
            // Dont allow editing of Home node
            e.Cancel = true;
        }
        else
        {
            SimpleSiteMapProvider.ClearFromCache();
        }
    }

    protected void OnUpdated(object sender, EventArgs e)
    {
        Response.Redirect(Request.Path);
    }

    /// <summary>
    /// Renders a list of child nodes for the input node
    /// This method is necessarily messy since it prints out HTML
    /// </summary>
    /// <param name="node"></param>
    /// <returns></returns>
    protected string RenderMenu(SiteMapNode parentNode)
    {
        StringBuilder result = new StringBuilder();
        // Render Home (root node)
        if (parentNode == SiteMap.RootNode)
        {
            result.AppendLine("<ul id='rootNode'>");
            // Add LI tag
            string css = (parentNode == SiteMap.CurrentNode) ? "selected" : String.Empty;
            string id = parentNode["id"];
            string title = System.Security.SecurityElement.Escape(parentNode.Title);
            result.AppendLine(String.Format("<li id='node{0}' class='{1}' title='{2}' noDrag='true' noSiblings='true'>", id, css, title));
            // Add A tag
            result.Append(String.Format("<a href='{0}'>{1}</a>", this.ResolveUrl(parentNode.Url), parentNode.Title));
        }
        // Render Children
        if (parentNode.HasChildNodes)
        {
            // Add UL tag
            result.AppendLine("<ul>");
            foreach (SiteMapNode node in parentNode.ChildNodes)
            {
                // Add LI tag
                string css = (node == SiteMap.CurrentNode) ? "selected" : String.Empty;
                string id = node["id"];
                string title = System.Security.SecurityElement.Escape(node.Title);
                bool isVisible = (node["display"] != null && Convert.ToBoolean(node["display"]));
                bool isRedirect = !String.IsNullOrEmpty(node["redirect"]);
                result.Append(String.Format("<li id='node{0}' class='{1}' title='{2}'>", id, css, title));
                // Add A tag
                result.Append(String.Format("<a href='{0}' {1}>{2}</a>", this.ResolveUrl(node.Url), isVisible ? (isRedirect ? " style='color: #6666ff'" : "") : " style='color: #cccccc'", node.Title));
                // Close Add Hide and Redirect checkboxes
                result.Append(String.Format(@"<span><input type='checkbox' name='hide' {0} onclick='hideChildren(this)'/>hide</span>", !isVisible ? "checked" : ""));
                result.Append(String.Format(@"<span><input type='checkbox' name='isRedirect' {0} onclick='showRedirect(this)'/>redirect <input type='text' name='redirect' value='" + node["redirect"] + "' style='display:{1}' /></span>", isRedirect ? "checked" : "", isRedirect ? "" : "none"));
                // Add children
                if (node.HasChildNodes)
                {
                    result.AppendLine();
                    result.Append(RenderMenu(node));
                }
                // Close LI tag
                result.AppendLine("</li>");
            }
            // Close UL tag
            result.AppendLine("</ul>");
        }
        // Close LI and UL tag (for Home - root node)
        if (parentNode == SiteMap.RootNode)
            result.AppendLine("</li></ul>");
        return result.ToString();
    }

    /// <summary>
    /// Save an xml tree representation of the sitemap
    /// </summary>
    protected void SaveTree(object sender, EventArgs e)
    {
        if (!String.IsNullOrEmpty(Request.Form["xmlNodeTree"]))
        {
            string xmlNodeTree = Request.Form["xmlNodeTree"];
            try
            {
                // Load the XML Node Tree
                XmlDocument doc = new XmlDocument();
                doc.LoadXml(xmlNodeTree);
                // Parse the document element
                SaveChildren(doc.DocumentElement);
                Utils.ClearCache();
                Response.Redirect(Request.Path);
            }
            catch (Exception ex)
            {
                // Problems parsing XML or writing to DB most likely
                // Notify user
                lblMessage.Text = Utils.Localise("msgError") + " " + ex.Message;
                lblMessage.Visible = true;
            }
        }
    }

    /// <summary>
    /// Recursive method to save children of each node
    /// of an xml representation of the sitemap
    /// </summary>
    /// <param name="parentNode"></param>
    protected void SaveChildren(XmlNode parentNode)
    {
        int parentID = Convert.ToInt32(parentNode.Attributes["id"].Value);
        foreach (XmlNode node in parentNode.ChildNodes)
        {
            // Obtain data about this page
            int pageID = Convert.ToInt32(node.Attributes["id"].Value);
            string pageTitle = node.Attributes["title"].Value.ToString();
            string redirectUrl = node.Attributes["redirect"].Value.ToString();
            bool display = Convert.ToBoolean(node.Attributes["display"].Value);
            int displayOrder = Convert.ToInt32(node.Attributes["displayOrder"].Value);
            // Check Page in catalog for comparison
            if (Utils.PageCatalog.ContainsKey(pageID))
            {
                VisualSite.Entities.Page page = Utils.PageCatalog[pageID];
                // Modify if there are any changes
                if (parentID != page.ParentID || pageTitle != page.Title || redirectUrl != page.RedirectUrl || display != page.Display || displayOrder != page.DisplayOrder)
                    DAL.UpdatePage(pageID, pageTitle, parentID, redirectUrl, display, displayOrder);
            }
            // Save children
            if (node.HasChildNodes)
                SaveChildren(node);
        }
    }
}
