using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Web;
using System.Web.UI;
using VisualSite;
using VisualSite.Entities;

public partial class Admin_Settings : System.Web.UI.Page
{
    protected void Page_PreInit(object sender, EventArgs e)
    {
        if (Utils.TemplateFile != String.Empty)
            Page.MasterPageFile = Utils.TemplateFile;
    }

    protected void Page_PreRender(object sender, EventArgs e)
    {
        PopulateForm();
    }

    protected void ClearCache(object sender, EventArgs e)
    {
        string message = Utils.ClearCache();
        lblMessage.Text = String.Format(Utils.Localise("msgClearCache"), message);
        lblMessage.Visible = true;
    }

    protected void PopulateForm()
    {
        // Title is derived from the name
        // of the root node
        textSiteTitle.Text = Utils.SiteTitle;
        // The rest of the settings are populated
        // form the database
        foreach(Setting setting in DAL.GetSettings())
        {
            if (setting.Name == "SiteDescription")
                textSiteDescription.Text = setting.Value;
            if (setting.Name == "Keywords")
                textKeywords.Text = setting.Value;
            if (setting.Name == "Locale")
                dropLanguage.SelectedValue = setting.Value;
            // Templates are populated with a repeater below
            if (setting.Name == "FriendlyUrls")
                if (setting.Value == "ON")
                    chkFriendlyUrlsOn.Checked = true;
                else 
                    chkFriendlyUrlsOff.Checked = true;
            if (setting.Name == "Compression")
                if (setting.Value == "ON")
                    chkCompressionOn.Checked = true;
                else
                    chkCompressionOff.Checked = true;
            if (setting.Name == "Backup")
                if (setting.Value == "ON")
                    chkBackupOn.Checked = true;
                else
                    chkBackupOff.Checked = true;
            if (setting.Name == "CacheDuration")
                if (setting.Value == "0")
                    chkCacheOff.Checked = true;
                else if (setting.Value == "180")
                    chkCacheLong.Checked = true;
                else
                    chkCacheNormal.Checked = true;
        }
    }

    protected void SaveForm(object sender, EventArgs e)
    {
        try
        {
            // Update site title
            Utils.SiteTitle = textSiteTitle.Text;
            // Update Settings
            DAL.UpdateSetting("SiteDescription", textSiteDescription.Text);
            DAL.UpdateSetting("Keywords", textKeywords.Text);
            DAL.UpdateSetting("Locale", dropLanguage.SelectedValue);
            DAL.UpdateSetting("FriendlyUrls", (chkFriendlyUrlsOn.Checked) ? "ON" : "OFF");
            DAL.UpdateSetting("Backup", (chkBackupOn.Checked) ? "ON" : "OFF");
            DAL.UpdateSetting("Compression", (chkCompressionOn.Checked) ? "ON" : "OFF");
            DAL.UpdateSetting("CacheDuration", (chkCacheNormal.Checked) ? "30" : (chkCacheOff.Checked) ? "0" : "180");
            string templateName = Request.Form["templateName"];
            if (!String.IsNullOrEmpty(templateName))
                DAL.UpdateSetting("SiteTemplate", String.Format(Constants.TEMPLATE_FOLDER + @"{0}/{0}.master", templateName.Replace(".master", "")));
            // Clear cache and reload
            Utils.ClearCache();
            Response.Redirect(Request.Path);
        }
        catch (Exception ex) 
        {
            // Output error message
            lblMessage.Text = Utils.Localise("msgUpdateError") + " " + ex.Message;
            lblMessage.Visible = true;
        }
    }
}
