using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Web.Compilation;
using System.CodeDom;

namespace VisualSite
{
    /// <summary>
    /// LocalisedExpressionBuilder creates an expression builder
    /// that helps the task of localising the application
    /// Obtains string literal <%$ Localise: Key %> for webpage use
    /// 
    /// Add to web.config as follows:
    ///   <compilation debug="true">
    ///    <expressionBuilders>
    ///     <add expressionPrefix="Localise" type="VisualSite.LocalisedExpresionBuilder" />
    ///    </expressionBuilders>
    ///   </compilation>
    ///
    /// </summary>
    public class LocalisedExpresionBuilder : ExpressionBuilder
    {
        /// <summary>
        /// Public Constructors
        /// </summary>
        public LocalisedExpresionBuilder() { }

        /// <summary>
        /// Obtains Localisation literal
        /// </summary>
        /// <param name="entry">Entry</param>
        /// <param name="parsedData">Parsed Data</param>
        /// <param name="context">Context</param>
        /// <returns>Code expresion</returns>
        public override CodeExpression GetCodeExpression(BoundPropertyEntry entry, object parsedData, ExpressionBuilderContext context)
        {
            return new CodeMethodInvokeExpression(
                new CodeMethodReferenceExpression(
                    new CodeTypeReferenceExpression(
                        typeof(LocalisedExpresionBuilder)),
                    "GetLocalise"),
                new CodePrimitiveExpression(entry.Expression));
        }

        /// <summary>
        /// Gets a localised string from Global Resources
        /// </summary>
        /// <param name="expression">Resource Key for Localisation</param>
        /// <returns>Localised string</returns>
        public static object GetLocalise(string expression)
        {
            return Utils.Localise(expression);
        }
    }
}