﻿using System;
using System.Collections.Generic;
using System.Web;
using VisualSite;
using VisualSite.Entities;

/// <summary>
/// The breadcrumb trail renders a list of nodes up the hierarchy
/// of pages, the output should look like this to the user:
/// 
///   Home » Services » Service A
/// 
/// The control can be rendered as an unordered list <ul></ul>
/// with <a> tag links to each page (this will need CSS formatting)
/// or alternatively as simple text.
/// </summary>
public partial class Components_Breadcrumb : System.Web.UI.UserControl
{
    // Set some local fields.
    private Dictionary<int, Page> _pageCatalog = Utils.PageCatalog;
    private int _startingNodeID = Utils.PageID;
    private bool _renderAsText = false;

    /// <summary>
    /// StartingNodeID sets the page from which
    /// the breadcrumb will be rendered
    /// </summary>
    public int StartingNodeID
    {
        get { return _startingNodeID; }
        set { _startingNodeID = value; }
    }

    /// <summary>
    /// Render as text allows rendering of the control 
    /// as text rather than <ul><li></li></ul> unordered list
    /// </summary>
    public bool RenderAsText
    {
        get { return _renderAsText; }
        set { _renderAsText = value; }
    }

    /// <summary>
    /// Overrides the base Render method to allow for rendering 
    /// of the page as text rather than as an unordered list
    /// </summary>
    /// <param name="output"></param>
    protected override void Render(System.Web.UI.HtmlTextWriter output)
    {
        if (_renderAsText)
        {
           output.Write(Utils.GetBreadcrumb(_startingNodeID));
        } else
            base.Render(output);
    }

}
