using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using VisualSite;

public partial class Controls_Content : System.Web.UI.UserControl
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Utils.IsUserAuthenticated)
        {
            // Show Edit Mode
            frmPage.Visible = true;
            validSummary.Visible = true;
            // Initialise Form for user editing
            if (Request.QueryString[Constants.ID_KEY] == "-1")
            {
                frmPage.ChangeMode(FormViewMode.Insert);
            }
            else if (Request.QueryString[Constants.ID_KEY] != "1") // Cant delete home, that'd be bad
            {
                try
                {
                    frmPage.FindControl("btnDelete").Visible = true;
                }
                catch { }
            }
        }
    }

    protected void Page_PreRender(object sender, EventArgs e)
    {
        if (Utils.IsUserAuthenticated)
            if (Request.QueryString[Constants.ID_KEY] == "-1")
            {
                if (!String.IsNullOrEmpty(Request.QueryString["AddFiles"]))
                {
                    foreach (string file in Request.QueryString["AddFiles"].Split(','))
                    {
                            InsertFile(file);
                    }
                }
            }
    }

    protected override void Render(HtmlTextWriter output)
    {
        /// This method overrides the HTML output of the control 
        /// for public (non-authenticated) access to show only the 
        /// page body stored in the database.
        /// This is used to ensure that none of the ASP editing
        /// controls appear in the source of the page.
        if (!Utils.IsUserAuthenticated)
            if (Utils.PageCatalog.ContainsKey(Utils.PageID))
                output.Write(Utils.PageCatalog[Utils.PageID].Body);
            else
                output.Write("Problem reading the database. ");
        else
            RenderChildren(output);
    }

    protected void HandleException(object sender, FormViewUpdatedEventArgs e)
    {
        if (e.Exception != null)
        {
            lblMessage.Text = Utils.Localise("msgUpdateError") + " " + e.Exception.InnerException.Message;
            lblMessage.Visible = true;
            e.ExceptionHandled = true;
        }
        else
        {
            Utils.ClearCache();
            // Here we redirect the user to the new page, bearing in mind we might
            // have to do a url redirection to a page using the new Title
            Utils.Go(Utils.PageID);
        }
    }

    /// When inserting pages we store the Page ID temporarily under a
    /// local variable to be called up later by FormViewInserted Event.
    /// This is used to redirect the user to the correct ID just after 
    /// page creation
    private int _pageID = -1;
    protected void OnInserted(object sender, ObjectDataSourceStatusEventArgs e)
    {
        _pageID = Convert.ToInt32(e.ReturnValue);
    }

    protected void HandleException(object sender, FormViewInsertedEventArgs e)
    {
        if (e.Exception != null)
        {
            lblMessage.Text = Utils.Localise("msgInsertError") + " " + e.Exception.InnerException.Message;
            lblMessage.Visible = true;
            e.ExceptionHandled = true;
        }
        else
        {
            Utils.ClearCache();
            // Here is where we use PageID collected above to redirect 
            // the user to the correct page.
            if (_pageID > 1)
                Utils.Go(_pageID);
            else
                Utils.GoHome();
        }
    }

    protected void HandleException(object sender, FormViewDeletedEventArgs e)
    {
        if (e.Exception != null)
        {
            lblMessage.Text = Utils.Localise("msgDeleteError") + " " + e.Exception.InnerException.Message;
            lblMessage.Visible = true;
            e.ExceptionHandled = true;
        }
        else
        {
            Utils.ClearCache();
            Utils.GoHome();
        }
    }

    protected void FormBound(object sender, EventArgs e)
    {
        DropDownList listParent = frmPage.FindControl("listParent") as DropDownList;
        if (listParent != null)
        {
            if (listParent.SelectedValue == "0" && Utils.PageID == 1)
            {
                // Home
                listParent.Enabled = false;
                // Remove Delete Button
                try { frmPage.FindControl("btnDelete").Visible = false; }
                catch { }
            }
            else if (!String.IsNullOrEmpty(listParent.SelectedValue))
            {
                // Remove Root from pulldown
                listParent.Items.Remove(listParent.Items[0]);
                // Remove all hidden pages
                foreach (VisualSite.Entities.Page page in DAL.GetMenuItems(Convert.ToInt32(listParent.SelectedValue)))
                    if (!page.Display)
                        // Remove hidden item only if its not already chosen
                        if (listParent.SelectedValue != page.ID.ToString())
                        {
                            ListItem hiddenItem = listParent.Items.FindByValue(page.ID.ToString());
                            listParent.Items.Remove(hiddenItem);
                        }
            }
        }
    }

    protected string GetConfirmPageDelete()
    {
        // If the page has children mention how many children in prompt
        string result = VisualSite.Utils.Localise("msgConfirmPageDelete");
        if (Utils.PageID > 1) {
            List<VisualSite.Entities.Page> childPages = DAL.GetPagesByParentID(Utils.PageID);
            if (childPages.Count > 0)
                result = String.Format(VisualSite.Utils.Localise("msgConfirmPageDeleteWithChildren"), childPages.Count);
        }
        return result;
    }

    private void InsertFile(string fileName)
    {
        TextBox txtBody = frmPage.FindControl("txtBody") as TextBox;
        if (txtBody != null && !String.IsNullOrEmpty(fileName))
        {
            txtBody.Text = String.Format(@"<img src='{0}' style='float:right ;margin:0px 0px 20px 20px;'/>", ResolveUrl(Constants.FILE_FOLDER + fileName)) + txtBody.Text;
        }
    }
}
