﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Xml;
using System.Text;
using VisualSite;
using VisualSite.Entities;

public partial class rss : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Clear any previous output from the buffer
        Response.Clear();
        Response.ContentType = "text/xml";
        XmlTextWriter feedWriter
          = new XmlTextWriter(Response.OutputStream, Encoding.UTF8);
        // Start Document
        feedWriter.WriteStartDocument();

        // Activate sitemap (in case items are not in cache)
        SiteMapNode node = SiteMap.RootNode;

        // Continue rendering based on format
        if (Request.QueryString["format"] == "atom")
            RenderAtomXml(feedWriter);
        else
            RenderRssXml(feedWriter);
        
        // Close off document
        feedWriter.WriteEndDocument();
        feedWriter.Flush();
        feedWriter.Close();

        Response.End();
    }

    /// <summary>
    /// Render output in RSS format
    /// http://www.rssboard.org/rss-specification
    /// </summary>
    /// <param name="feedWriter"></param>
    private void RenderRssXml(XmlTextWriter feedWriter)
    {
        // Write RSS Tags
        feedWriter.WriteStartElement("rss");
        feedWriter.WriteAttributeString("version", "2.0");

        feedWriter.WriteStartElement("channel");
        feedWriter.WriteElementString("title", Utils.SiteTitle);
        feedWriter.WriteElementString("language", Utils.Locale);
        feedWriter.WriteElementString("link", Utils.SiteUrl + Request.ApplicationPath);
        feedWriter.WriteElementString("description", Utils.GetSetting("SiteDescription"));
        feedWriter.WriteElementString("copyright", 
            String.Format(Utils.Localise("lblCopyright"), 
            DateTime.Now.Year, Utils.SiteTitle));

        // Loop through all pages in the catalog
        foreach (KeyValuePair<int, VisualSite.Entities.Page> entry in Utils.PageCatalog)
        {
            // Load page data and check if shown or hidden
            VisualSite.Entities.Page page = entry.Value;
            if (page.Display)
            {
                // Add RSS tags for each entry
                feedWriter.WriteStartElement("item");
                feedWriter.WriteElementString("title", page.Title);
                string description = page.Body;
                if (!String.IsNullOrEmpty(description))
                {
                    // Remove markup
                    description = Utils.RemoveMarkup(description);
                    // Use teaser (beginning 500 characters)
                    if (description.Length > 500)
                        description = description.Substring(0, 500) + "...";
                }
                feedWriter.WriteElementString("description", description);
                feedWriter.WriteElementString("id", Utils.SiteUrl + ResolveUrl(Utils.GetUrl(page.ID)));
                feedWriter.WriteElementString("link", Utils.SiteUrl + ResolveUrl(Utils.GetUrl(page.ID)));
                feedWriter.WriteElementString("pubDate",
                    page.PublishDate.ToUniversalTime().ToString(Constants.DATE_UTC_FORMAT));
                feedWriter.WriteEndElement();
            }
        }

        // Close all open tags tags
        feedWriter.WriteEndElement();
        feedWriter.WriteEndElement();
    }

    /// <summary>
    /// Render output in Atom format
    /// http://tools.ietf.org/rfc/rfc4287.txt
    /// </summary>
    /// <param name="feedWriter"></param>
    private void RenderAtomXml(XmlTextWriter feedWriter)
    {
        // Add Atom Stylesheet
        feedWriter.WriteProcessingInstruction("xml-stylesheet", "href='atom.css' type='text/css'");

        // Write Atom Tags
        feedWriter.WriteStartElement("feed", "http://www.w3.org/2005/Atom");
        feedWriter.WriteElementString("title", Utils.SiteTitle);
        feedWriter.WriteElementString("subtitle", Utils.GetSetting("SiteDescription"));
        feedWriter.WriteStartElement("link");
        feedWriter.WriteAttributeString("href", VisualSite.Utils.SiteUrl + Request.ApplicationPath);
        feedWriter.WriteAttributeString("rel", "alternate");
        feedWriter.WriteAttributeString("application", "text/html");
        feedWriter.WriteEndElement();
        feedWriter.WriteStartElement("link");
        feedWriter.WriteAttributeString("href", Request.Url.OriginalString);
        feedWriter.WriteAttributeString("rel", "self");
        feedWriter.WriteAttributeString("application", "application/atom+xml");
        feedWriter.WriteEndElement();
        feedWriter.WriteElementString("id", 
            String.Format("tag:{0},{1}:site-{2}", 
            Request.Url.Host, DateTime.Now.Year, 
            Utils.SiteTitle.GetHashCode().ToString()));
        feedWriter.WriteElementString("updated", DateTime.Now.ToUniversalTime().ToString("s") + "Z");
        feedWriter.WriteStartElement("author");
        feedWriter.WriteElementString("name", "VisualSite User");
        feedWriter.WriteElementString("email", "user@visualsite.me");
        feedWriter.WriteEndElement();

        // Loop through all pages in the catalog
        foreach (KeyValuePair<int, VisualSite.Entities.Page> entry in Utils.PageCatalog)
        {
            // Load page data and check if shown or hidden
            VisualSite.Entities.Page page = entry.Value;
            if (page.Display)
            {
                // Add atom tags for each entry
                feedWriter.WriteStartElement("entry");
                feedWriter.WriteElementString("updated",
                    page.PublishDate.ToUniversalTime().ToString(Constants.DATE_UTC_FORMAT));
                feedWriter.WriteElementString("title", page.Title);
                feedWriter.WriteElementString("id",
                    String.Format("tag:{0},{1}:site-{2}.{3}",
                    Request.Url.Host, DateTime.Now.Year,
                    Utils.SiteTitle.GetHashCode().ToString(), page.ID));
                feedWriter.WriteStartElement("link");
                feedWriter.WriteAttributeString("href", VisualSite.Utils.SiteUrl + ResolveUrl(Utils.GetUrl(page.ID)));
                feedWriter.WriteValue(VisualSite.Utils.SiteUrl + ResolveUrl(Utils.GetUrl(page.ID)));
                feedWriter.WriteEndElement();
                // Write Summary
                string summary = page.Body;
                if (!String.IsNullOrEmpty(summary))
                {
                    // Remove markup
                    summary = Utils.RemoveMarkup(summary);
                    // Use teaser (beginning 500 characters)
                    if (summary.Length > 500)
                        summary = summary.Substring(0, 500) + "...";
                }
                feedWriter.WriteElementString("summary", summary);
                feedWriter.WriteEndElement();
            }
        }

        // Close all open tags tags
        feedWriter.WriteEndElement();
    }

}
