﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using VisualSite;

public partial class SearchResults : System.Web.UI.Page
{
    protected int ResultCount;
    protected string Query;
    protected int PageSize;
    protected int CurrentPage;
    protected int MaxPage;
    protected TimeSpan QueryTime;

    protected void Page_PreInit(object sender, EventArgs e)
    {
        // Find Global Template
        if (Utils.TemplateFile != String.Empty)
            Page.MasterPageFile = Utils.TemplateFile;
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        DateTime start = DateTime.Now;
        // Fetch query results
        Query = Request.QueryString["q"];
        if (Query == null) Query = String.Empty;
        if (Query.Length > 0) Query = Utils.RemoveMarkup(Query);
        SearchManager searchManager = new SearchManager();
        List<SearchResult> results = searchManager.GetResults(Query);
        // Calculate some values
        ResultCount = results.Count;
        PageSize = Constants.SEARCH_RESULT_PAGE_SIZE;
        MaxPage = ((ResultCount - 1) / PageSize) + 1;
        CurrentPage = 1;
        // Check to see if we should be filtering results
        if (Constants.SEARCH_RESULT_PAGE_SIZE > 0 && ResultCount > Constants.SEARCH_RESULT_PAGE_SIZE)
        {
            // Get Current Page
            if (!String.IsNullOrEmpty(Request.QueryString["p"]))
                try
                {
                    CurrentPage = Convert.ToInt32(Request.QueryString["p"]);
                    if (CurrentPage < 1) CurrentPage = 1;
                    if (CurrentPage > MaxPage) CurrentPage = MaxPage;
                }
                catch { }
            // Display pager
            List<string[]> pages = new List<string[]>();
            for (int i = 1; i <= MaxPage; i++)
            {
                pages.Add(new string[2] {i.ToString(),
                      (i == CurrentPage) ? "selected" : ""});
            }
            listSearchPager.DataSource = pages;
            listSearchPager.Visible = true;
            listSearchPager.DataBind();
            // Filter Results to current page only
            List<SearchResult> filteredResults = new List<SearchResult>();
            if (CurrentPage > 1 && results.Count >= (CurrentPage-1) * PageSize)
                for (int i = ((CurrentPage - 1) * PageSize); i < CurrentPage * PageSize; i++)
                {
                    if (i < ResultCount)
                        filteredResults.Add(results[i]);
                }
            else
                for (int i = 0; i < PageSize; i++)
                {
                    filteredResults.Add(results[i]);
                }
            results = filteredResults;
        }
        // Bind Results for output
        listSearchResults.DataSource = results;
        listSearchResults.DataBind();
        // Set timer
        QueryTime = DateTime.Now.Subtract(start);
    }

    /// <summary>
    /// Gets the result count
    /// </summary>
    /// <returns></returns>
    protected string GetResultCount()
    {
        string result = String.Empty;
        if (ResultCount == 0)
        {
            result = String.Format(VisualSite.Utils.Localise("lblSearchResultsEmpty"), Query);
        }
        else
        {
            // Show total number of results
            result = String.Format(VisualSite.Utils.Localise("lblSearchResultsCount"), ResultCount, Query);
            // If results are paged show current items on display
            if (Constants.SEARCH_RESULT_PAGE_SIZE > 0 && ResultCount > Constants.SEARCH_RESULT_PAGE_SIZE)
            {
                int start = ((CurrentPage - 1) * PageSize) + 1;
                int end  = start + PageSize - 1 ;
                if (end > ResultCount) end = ResultCount;
                result += " " + String.Format(VisualSite.Utils.Localise("lblSearchResultsFilter"), start, end);
            }
        }
        return result;
    }
}